#
# Lockstep Platform SDK for Python
#
# (c) 2021-2022 Lockstep, Inc.
#
# For the full copyright and license information, please view the LICENSE
# file that was distributed with this source code.
#
# @author     Lockstep Network <support@lockstep.io>
# @copyright  2021-2022 Lockstep, Inc.
# @link       https://github.com/Lockstep-Network/lockstep-sdk-python
#


from dataclasses import dataclass
from lockstep.models.connectorinfomodel import ConnectorInfoModel

@dataclass
class ErpInfoModel:
    """
    Represents the ERP object sent in a provisioning request
    """

    appId: str | None = None
    data: ConnectorInfoModel | None = None

